Class: SkyApi::NetworkConnectionSchema

Inherits:
Object
  • Object
show all
Defined in:
lib/sky_api/models/network_connection_schema.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ NetworkConnectionSchema

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/sky_api/models/network_connection_schema.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SkyApi::NetworkConnectionSchema` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SkyApi::NetworkConnectionSchema`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.key?(:'connected_at')
    self.connected_at = attributes[:'connected_at']
  end

  if attributes.key?(:'height')
    self.height = attributes[:'height']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'is_trusted_peer')
    self.is_trusted_peer = attributes[:'is_trusted_peer']
  end

  if attributes.key?(:'last_received')
    self.last_received = attributes[:'last_received']
  end

  if attributes.key?(:'last_sent')
    self.last_sent = attributes[:'last_sent']
  end

  if attributes.key?(:'listen_port')
    self.listen_port = attributes[:'listen_port']
  end

  if attributes.key?(:'mirror')
    self.mirror = attributes[:'mirror']
  end

  if attributes.key?(:'outgoing')
    self.outgoing = attributes[:'outgoing']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'unconfirmed_verify_transaction')
    self.unconfirmed_verify_transaction = attributes[:'unconfirmed_verify_transaction']
  end

  if attributes.key?(:'user_agent')
    self.user_agent = attributes[:'user_agent']
  end
end

Instance Attribute Details

#addressObject

Returns the value of attribute address.



17
18
19
# File 'lib/sky_api/models/network_connection_schema.rb', line 17

def address
  @address
end

#connected_atObject

Returns the value of attribute connected_at.



19
20
21
# File 'lib/sky_api/models/network_connection_schema.rb', line 19

def connected_at
  @connected_at
end

#heightObject

Returns the value of attribute height.



21
22
23
# File 'lib/sky_api/models/network_connection_schema.rb', line 21

def height
  @height
end

#idObject

Returns the value of attribute id.



23
24
25
# File 'lib/sky_api/models/network_connection_schema.rb', line 23

def id
  @id
end

#is_trusted_peerObject

Returns the value of attribute is_trusted_peer.



25
26
27
# File 'lib/sky_api/models/network_connection_schema.rb', line 25

def is_trusted_peer
  @is_trusted_peer
end

#last_receivedObject

Returns the value of attribute last_received.



27
28
29
# File 'lib/sky_api/models/network_connection_schema.rb', line 27

def last_received
  @last_received
end

#last_sentObject

Returns the value of attribute last_sent.



29
30
31
# File 'lib/sky_api/models/network_connection_schema.rb', line 29

def last_sent
  @last_sent
end

#listen_portObject

Returns the value of attribute listen_port.



31
32
33
# File 'lib/sky_api/models/network_connection_schema.rb', line 31

def listen_port
  @listen_port
end

#mirrorObject

Returns the value of attribute mirror.



33
34
35
# File 'lib/sky_api/models/network_connection_schema.rb', line 33

def mirror
  @mirror
end

#outgoingObject

Returns the value of attribute outgoing.



35
36
37
# File 'lib/sky_api/models/network_connection_schema.rb', line 35

def outgoing
  @outgoing
end

#stateObject

Returns the value of attribute state.



37
38
39
# File 'lib/sky_api/models/network_connection_schema.rb', line 37

def state
  @state
end

#unconfirmed_verify_transactionObject

Returns the value of attribute unconfirmed_verify_transaction.



39
40
41
# File 'lib/sky_api/models/network_connection_schema.rb', line 39

def unconfirmed_verify_transaction
  @unconfirmed_verify_transaction
end

#user_agentObject

Returns the value of attribute user_agent.



41
42
43
# File 'lib/sky_api/models/network_connection_schema.rb', line 41

def user_agent
  @user_agent
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/sky_api/models/network_connection_schema.rb', line 66

def self.attribute_map
  {
    :'address' => :'address',
    :'connected_at' => :'connected_at',
    :'height' => :'height',
    :'id' => :'id',
    :'is_trusted_peer' => :'is_trusted_peer',
    :'last_received' => :'last_received',
    :'last_sent' => :'last_sent',
    :'listen_port' => :'listen_port',
    :'mirror' => :'mirror',
    :'outgoing' => :'outgoing',
    :'state' => :'state',
    :'unconfirmed_verify_transaction' => :'unconfirmed_verify_transaction',
    :'user_agent' => :'user_agent'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



231
232
233
# File 'lib/sky_api/models/network_connection_schema.rb', line 231

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/sky_api/models/network_connection_schema.rb', line 85

def self.openapi_types
  {
    :'address' => :'String',
    :'connected_at' => :'Integer',
    :'height' => :'Integer',
    :'id' => :'Integer',
    :'is_trusted_peer' => :'Boolean',
    :'last_received' => :'Integer',
    :'last_sent' => :'Integer',
    :'listen_port' => :'Integer',
    :'mirror' => :'Integer',
    :'outgoing' => :'Boolean',
    :'state' => :'String',
    :'unconfirmed_verify_transaction' => :'NetworkConnectionSchemaUnconfirmedVerifyTransaction',
    :'user_agent' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/sky_api/models/network_connection_schema.rb', line 198

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      address == o.address &&
      connected_at == o.connected_at &&
      height == o.height &&
      id == o.id &&
      is_trusted_peer == o.is_trusted_peer &&
      last_received == o.last_received &&
      last_sent == o.last_sent &&
      listen_port == o.listen_port &&
      mirror == o.mirror &&
      outgoing == o.outgoing &&
      state == o.state &&
      unconfirmed_verify_transaction == o.unconfirmed_verify_transaction &&
      user_agent == o.user_agent
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/sky_api/models/network_connection_schema.rb', line 259

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    SkyApi.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/sky_api/models/network_connection_schema.rb', line 324

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/sky_api/models/network_connection_schema.rb', line 238

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


218
219
220
# File 'lib/sky_api/models/network_connection_schema.rb', line 218

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



224
225
226
# File 'lib/sky_api/models/network_connection_schema.rb', line 224

def hash
  [address, connected_at, height, id, is_trusted_peer, last_received, last_sent, listen_port, mirror, outgoing, state, unconfirmed_verify_transaction, user_agent].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



173
174
175
176
# File 'lib/sky_api/models/network_connection_schema.rb', line 173

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



304
305
306
# File 'lib/sky_api/models/network_connection_schema.rb', line 304

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



310
311
312
313
314
315
316
317
318
# File 'lib/sky_api/models/network_connection_schema.rb', line 310

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



298
299
300
# File 'lib/sky_api/models/network_connection_schema.rb', line 298

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



180
181
182
183
184
# File 'lib/sky_api/models/network_connection_schema.rb', line 180

def valid?
  state_validator = EnumAttributeValidator.new('String', ["pending", "connected", "introduced"])
  return false unless state_validator.valid?(@state)
  true
end